@@ -54,8 +54,9 @@ G_BEGIN_DECLS
 #define GLIBTOP_SYSDEPS_PROC_WD		25
 #define GLIBTOP_SYSDEPS_PROC_AFFINITY	26
 #define GLIBTOP_SYSDEPS_PROC_IO	27
+#define GLIBTOP_SYSDEPS_DISK	28
 
-#define GLIBTOP_MAX_SYSDEPS		28
+#define GLIBTOP_MAX_SYSDEPS		29
 
 /* The 'features' args to glibtop_init_* is an unsigned long */
 G_STATIC_ASSERT((1UL << (GLIBTOP_MAX_SYSDEPS - 1)) <= ULONG_MAX);
@@ -95,7 +96,7 @@ struct _glibtop_sysdeps
 	guint64	proc_wd;		/* glibtop_proc_wd	*/
 	guint64	proc_affinity;		/* glibtop_proc_affinity */
 	guint64	proc_io;		/* glibtop_proc_io */
-	guint64	reserved0;
+	guint64 disk;			/* glibtop_disk		*/
 	guint64	reserved1;
 	guint64	reserved2;
 	guint64	reserved3;
