@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with LibGTop; see the file COPYING. If not, write to the
-   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef __GLIBTOP_MACHINE_H__
@@ -36,8 +36,6 @@
 
 G_BEGIN_DECLS
 
-typedef struct _glibtop_machine glibtop_machine;
-
 struct _glibtop_machine
 {
 	uid_t uid, euid;
